#!/bin/sh
#set -e
#set -x

FONT_SIZE="24"

OLD_KERNEL="4.10.0-24-generic"
KERNEL="4.16.0-rc3+"

if [ "$(lspci -n | grep -i 14F1:8880)" != "" ]; then
  # H1265 tuner
  OLD_DRIVER="cx2388x-$OLD_KERNEL"
  DRIVER="cx2388x-$KERNEL"
else
  OLD_DRIVER="mww-$OLD_KERNEL"
  DRIVER="mww-$KERNEL"
fi

# Clear the existing apt lists in case they're stale
sudo rm -rf /var/lib/apt/lists/*

# Remove old driver
if [ "$(dpkg-query --showformat='${Version}' --show $OLD_DRIVER)" != "" ]; then
  sudo apt remove $OLD_DRIVER --fix-broken --allow-unauthenticated -y > /data/logs/updateTVtuner.log 2>&1
fi

# Install new driver
sleep 15s
if [ -e /home/true/$DRIVER*_amd64.deb ]; then
  sudo dpkg --debug=73 -i /home/true/$DRIVER*_amd64.deb >> /data/logs/updateTVtuner.log 2>&1
else
  sudo apt update >> /data/logs/updateTVtuner.log 2>&1
  sudo apt install $DRIVER --fix-broken --allow-unauthenticated -y >> /data/logs/updateTVtuner.log 2>&1
fi
sudo dpkg --configure -a >> /data/logs/updateTVtuner.log 2>&1

# Verify driver was installed
if [ "$(dpkg-query --showformat='${Version}' --show $DRIVER)" = "" ]; then
  echo "New driver failed to install." >> /data/logs/updateTVtuner.log

  zenity --info --timeout=5 \
         --text="<span font=\"$FONT_SIZE\"> \n\n $DRIVER failed to install.\n\n</span>" >> /data/logs/updateTVtuner.log 2>&1
else
  echo "$DRIVER installed successfully v$(dpkg-query --showformat='${Version}' --show $DRIVER)" >> /data/logs/updateTVtuner.log

  zenity --info --timeout=5 \
         --text="<span font=\"$FONT_SIZE\"> \n\n $DRIVER installed successfully.\n\n</span>" >> /data/logs/updateTVtuner.log 2>&1

  if [ -e /home/true/$DRIVER*_amd64.deb ]; then
    sudo rm /home/true/$DRIVER*_amd64.deb
  fi

  REBOOT_SCRIPT=/home/true/.config/openbox/autostart.d/58_installTVdriver.sh
  if [ -e $REBOOT_SCRIPT ]; then
    sudo rm $REBOOT_SCRIPT
  fi
fi

